support Package
===============

:mod:`support` Package
----------------------

.. automodule:: numba.support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cffi_support` Module
--------------------------

.. automodule:: numba.support.cffi_support
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ctypes_support` Module
----------------------------

.. automodule:: numba.support.ctypes_support
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.support.numpy_support
    numba.support.tests

